function loadplayer()
	playerX = 15 -- X position of player
	playerY = 15 -- Y position of player

  playerwidth = 25
  playerheight = 36
  playerwidthwide = 36  --for wide sprites like rolling/sliding/diving
  playerheightlow = 24 --height when crouched, rolling, sliding, etc
  playerlowoffset = (playerheight-playerheightlow) --offset of shape when crouched so that the bottom is in the same location

  oldplayerX = 60 --used to calculate delta movement for animation
  oldplayerY = 60

  playermass = 30

  player = {}
  player.body = love.physics.newBody(world, playerX, playerY, playermass, 0)
  player.body:setInertia(0)
  player.shape = love.physics.newRectangleShape(player.body, 0, 0, playerwidth-16, playerheight, 0)
  player.shape:setData("Player")
  player.shape:setRestitution(0)
  player.shape:setFriction(.5)


--sensors
  player.feet = love.physics.newRectangleShape(player.body, 0, playerheight/2, playerwidth-20, 3, 0)
  player.feet:setData("playerfeet")
  player.feet:setSensor(true)

  player.right = love.physics.newRectangleShape(player.body, (playerwidth/2)-8, 0, 3, playerheight-8, 0)
  player.right:setData("playerright")
  player.right:setSensor(true)

  player.left = love.physics.newRectangleShape(player.body, (-(playerwidth/2))+8, 0, 3, playerheight-8, 0)
  player.left:setData("playerleft")
  player.left:setSensor(true)

  player.sensor = {}
  player.sensor.feet = 0
  player.sensor.right = 0
  player.sensor.left = 0

--animations
  player.runr = {}
	player.runr.sheet = love.graphics.newImage("img/player/runr.png")
	player.runr.sheet:setFilter('nearest', 'nearest') --second param only: nearest = pixel graphics, linear = anti-aliasing
  player.runr.anim = newAnimation(player.runr.sheet, playerwidth, playerheight, 0.15, 5)

  player.runl = {}
  player.runl.sheet = love.graphics.newImage("img/player/runl.png")
  player.runl.sheet:setFilter('nearest', 'nearest') --second param only: nearest = pixel graphics, linear = anti-aliasing
  player.runl.anim = newAnimation(player.runl.sheet, playerwidth, playerheight, 0.15, 5)

  player.jumpr = {}
  player.jumpr.sheet = love.graphics.newImage("img/player/jumpr.png")
  player.jumpr.sheet:setFilter('nearest', 'nearest')
  player.jumpr.anim = newAnimation(player.jumpr.sheet, playerwidth, playerheight, 0.15, 8)

  player.jumpl = {}
  player.jumpl.sheet = love.graphics.newImage("img/player/jumpl.png")
  player.jumpl.sheet:setFilter('nearest', 'nearest')
  player.jumpl.anim = newAnimation(player.jumpl.sheet, playerwidth, playerheight, 0.15, 8)

  player.rollr = {}
  player.rollr.sheet = love.graphics.newImage("img/player/rollr.png")
  player.rollr.sheet:setFilter('nearest', 'nearest')
  player.rollr.anim = newAnimation(player.rollr.sheet, playerwidthwide, playerheight, 0.06, 12)

  player.rolll = {}
  player.rolll.sheet = love.graphics.newImage("img/player/rolll.png")
  player.rolll.sheet:setFilter('nearest', 'nearest')
  player.rolll.anim = newAnimation(player.rolll.sheet, playerwidthwide, playerheight, 0.06, 12)

  player.standr = love.graphics.newImage("img/player/standr.png")
  player.standr:setFilter('nearest', 'nearest')

  player.standl = love.graphics.newImage("img/player/standl.png")
  player.standl:setFilter('nearest', 'nearest')

  player.wallslider = love.graphics.newImage("img/player/wallslider.png")
  player.wallslider:setFilter('nearest', 'nearest')

  player.wallslidel = love.graphics.newImage("img/player/wallslidel.png")
  player.wallslidel:setFilter('nearest', 'nearest')

  player.dirx = "right"
  player.state = "jump"


  playerloaded = 1
end

function playerupdate(dt)
  player.runr.anim:update(dt)
  player.runl.anim:update(dt)
  player.jumpr.anim:update(dt)
  player.jumpl.anim:update(dt)
  player.rollr.anim:update(dt)
  player.rolll.anim:update(dt)
end

function moveplayer()
  vx, vy = player.body:getLinearVelocity()

--jump
  if keyboard.w == 1 and player.sensor.feet ~= 0  then
    player.body:applyForce(0, -8000)
  end

--walljump
  if vy > 15 then
    if keyboard.w == 1 and player.sensor.feet == 0 and player.sensor.right ~= 0 then
      player.body: applyForce(-8000, -12000)
    end
  
    if keyboard.w == 1 and player.sensor.feet == 0 and player.sensor.left ~= 0 then
      player.body: applyForce(8000, -12000)
    end
  end

--x movement
  if keyboard.a == 1 and player.sensor.feet ~= 0 then
    player.body:applyForce(-1000, 0)
  end
  if keyboard.a == 1 and player.sensor.feet == 0 then
    player.body:applyForce(-100, 0)
  end

  if keyboard.d == 1 and player.sensor.feet ~= 0 then
    player.body:applyForce(1000, 0)
  end
  if keyboard.d == 1 and player.sensor.feet == 0 then
    player.body:applyForce(100, 0)
  end

  --debug jetpack to get out of holes while testing
  if keyboard.j == 1 then
    player.body:applyForce(0, -2000)
  end
  if keyboard.k == 1 then
    player.body:applyForce(0, 2000)
  end

  x1, y1, x2, y2, x3, y3, x4, y4 = player.shape:getPoints()

  x1 = x1 - 8  -- compensate for a narrower collision box than the player sprite

  playerX = x1
  playerY = y1

end

function deltamovement()
  dx = player.body:getX() - oldplayerX
  dy = player.body:getY() - oldplayerY

  oldplayerX = player.body:getX()
  oldplayerY = player.body:getY()

  return dx,dy
end

function playeranimate()
  dx,dy = deltamovement()
  local frame = 1

--jumping
  if player.sensor.feet == 0 and player.sensor.right == 0 and player.sensor.left == 0 then
    if dx > 0 then
      playerstate = "jumpr"
      player.dirx = "right"
      frame = player.jumpr.anim:getCurrentFrame()
      player.jumpr.anim:setDelay(frame, 2/((dx+dy)/2))
    end
    if dx < 0 then
      playerstate = "jumpl"
      player.dirx = "left"
      frame = player.jumpl.anim:getCurrentFrame()
      player.jumpl.anim:setDelay(frame, 2/((dx+dy)/2))
    else
      if player.dirx == "right" then
      playerstate = "jumpr"
      player.dirx = "right"
      frame = player.jumpr.anim:getCurrentFrame()
      player.jumpr.anim:setDelay(frame, 2/((dx+dy)/2))
      else
      playerstate = "jumpl"
      player.dirx = "left"
      frame = player.jumpl.anim:getCurrentFrame()
      player.jumpl.anim:setDelay(frame, 2/((dx+dy)/2))
      end
    end
  end

--wallsliding
  if player.sensor.feet == 0 and player.sensor.right ~= 0 then
    playerstate = "wallslider"
  elseif player.sensor.feet == 0 and player.sensor.left ~= 0 then
    playerstate = "wallslidel"
  end

--running
  if dx < 0 and player.sensor.feet ~= 0 then
    playerstate = "runl"
    player.dirx = "left"
    frame = player.runl.anim:getCurrentFrame()
    player.runl.anim:setDelay(frame, 0.3/math.abs(dx))  --animation plays faster as the player moves faster
  end
  if dx > 0 and player.sensor.feet ~= 0 then
    playerstate = "runr"
    player.dirx = "right"
    frame = player.runr.anim:getCurrentFrame()
    player.runr.anim:setDelay(frame, 0.3/dx)
  end

--standing
  if player.sensor.feet ~= 0 and dy == 0 and dx == 0 then
    if player.dirx == "right" then
    playerstate = "standr"
    player.runr.anim:reset()
    player.runl.anim:reset()
    end
    if player.dirx == "left" then
    playerstate = "standl"
    player.runr.anim:reset()
    player.runl.anim:reset()
    end
  end

--rolling
  if playerstate == "runr" and keyboard.shift == 1 then
    playerstate = "rollr"
    player.shape:destroy()
    player.shape = love.physics.newRectangleShape(player.body, 0, playerlowoffset, playerwidth-16, playerheightlow, 0)
  end
  if playerstate == "runl" and keyboard.shift == 1 then
    playerstate = "rolll"
    player.shape:destroy()
    player.shape = love.physics.newRectangleShape(player.body, 0, playerlowoffset, playerwidth-16, playerheightlow, 0)
  end
end

--to draw things at larger pixel locations (not inbetween pixels):
--math.round(playerX/camera.scalefactor))*camera.scalefactor, (math.round(playerY/camera.scalefactor))*camera.scalefactor)

function drawplayer()
  if playerstate == "jumpr" then
  player.jumpr.anim:draw(playerX, playerY)
  elseif playerstate == "jumpl" then
    player.jumpl.anim:draw(playerX, playerY)
  elseif playerstate == "standr" then
    love.graphics.draw(player.standr, playerX, playerY)
  elseif playerstate == "standl" then
    love.graphics.draw(player.standl, playerX, playerY)
  elseif playerstate == "runr" then
    player.runr.anim:draw(playerX, playerY)
  elseif playerstate == "runl" then
    player.runl.anim:draw(playerX, playerY)
  elseif playerstate == "wallslider" then
    love.graphics.draw(player.wallslider, playerX, playerY)
  elseif playerstate == "wallslidel" then
    love.graphics.draw(player.wallslidel, playerX, playerY)
  elseif playerstate == "rollr" then
    player.rollr.anim:draw(playerX, playerY)
  elseif playerstate == "rolll" then
    player.rolll.anim:draw(playerX, playerY)
  end
end